@@ -17,6 +17,12 @@ setClass("dwi",
                         source = "character"),
          )
 
+dwi <- function(object,  ...) cat("This object has class",class(object),"\n")
+setGeneric("dwi", function(object,  ...) 
+standardGeneric("dwi"))
+
+setClassUnion("narray",c("array","numeric"))
+
 setClass("dtiData",
          representation(si   = "array",
                         sdcoef = "numeric"),
@@ -139,6 +145,7 @@ setClass("dwiQball",
                         order  = "integer",
                         lambda = "numeric",
                         sphcoef = "array",
+                        varsphcoef = "array",
                         th0 = "array",
                         sigma  = "array",
                         scorr  = "array",
@@ -153,7 +160,7 @@ setClass("dwiQball",
             cat("invalid order of spherical harmonics \n")
             return(invisible(FALSE))
           }
-          if(object@what=="Qball"&any(dim(object@sphcoef)!=c((object@order+1)*(object@order+2)/2,object@ddim))) {
+          if(object@what%in%c("ODF","wODF","aODF")&any(dim(object@sphcoef)!=c((object@order+1)*(object@order+2)/2,object@ddim))) {
             cat("invalid dimension of ceofficient array \n")
             return(invisible(FALSE))
           }
@@ -179,8 +186,94 @@ setClass("dwiQball",
             cat("invalid length of bw\n")
             return(invisible(FALSE))
           }
-          if (!(object@what %in% c("Qball","ADC"))) {
-            cat("what should specify either Qball or ADC\n")
+          if (!(object@what %in% c("ODF","wODF","aODF","ADC"))) {
+            cat("what should specify ODF, wODF, aODF or ADC\n")
+            return(invisible(FALSE))
+          }
+         }
+         )
+setClass("dwiFiber",
+          representation(call = "list",
+                         fibers = "matrix",
+                         startind = "integer",
+                         roimask = "raw",
+                         method = "character",
+                         minanindex = "numeric",
+                         maxangle   = "numeric"),
+         contains=c("list","dwi"),
+         validity=function(object){
+            if(dim(object@fibers)[2]!=6) {
+            cat("invalid dimension of fibers matrix \n")
+            return(invisible(FALSE))
+            }
+         }
+        )
+setClass("dwiMixtensor",
+         representation(method = "character",
+                        ev     = "array",#length 2 (eigenvalues)
+                        mix    = "array",
+                        orient = "array",
+                        order  = "array",
+                        p      = "narray", # p in "method"=="Jian"
+                        th0    = "array",
+                        sigma  = "array",
+                        scorr  = "array",
+                        bw     = "numeric",
+                        mask   = "array",
+                        hmax   = "numeric",
+                        outlier = "numeric",
+                        scale  = "numeric"),
+         contains=c("list","dwi"),
+         validity=function(object){
+          if (any(dim(object@ev)!=c(2,object@ddim))) {
+            cat("invalid dimension of eigenvalue array ev \n")
+            return(invisible(FALSE))
+          }
+          if (any(dim(object@mix)[-1]!=object@ddim)) {
+            cat("invalid dimension of array of mixture weights \n")
+            return(invisible(FALSE))
+          }
+          if (any(dim(object@orient)[-2]!=c(2,object@ddim))) {
+            cat("invalid dimension of orientations array orient \n")
+            return(invisible(FALSE))
+          }
+          if (dim(object@orient)[2]!=dim(object@mix)[1]) {
+            cat("dimension of orientations array orient incompatible with
+                 number of mixtures \n")
+            return(invisible(FALSE))
+          }
+          if (any(dim(object@order)!=object@ddim)) {
+            cat("  \n")
+            return(invisible(FALSE))
+          }
+          if (any(object@mix<0)) {
+            cat("negative mixture coefficients \n")
+            return(invisible(FALSE))
+          }
+          if (any(dim(object@th0)!=object@ddim)) {
+            cat("invalid dimension of array th0\n")
+            return(invisible(FALSE))
+          }
+          if (any(dim(object@mask)!=object@ddim)) {
+            cat("dimension of mask:",dim(object@mask),"\n")
+            cat("should be:",object@ddim,"\n")
+            cat("invalid dimension of array mask\n")
+            return(invisible(FALSE))
+          }
+          if (!is.logical(object@mask)) {
+            cat("invalid type of array mask, should be logical\n")
+            return(invisible(FALSE))
+          }
+          if (length(dim(object@scorr))!=3) {
+            cat("invalid dimension of scorr\n")
+            return(invisible(FALSE))
+          }
+          if (length(object@bw)!=3) {
+            cat("invalid length of bw\n")
+            return(invisible(FALSE))
+          }
+          if (!(object@method %in% c("mixtensor","Jian","Jian2"))) {
+            cat("method should specify either mixtensor, Jian or Jian2\n")
             return(invisible(FALSE))
           }
          }
